(global-set-key (kbd "C-c a") 'org-agenda)

;;set priority range from A to C with default A
(setq org-highest-priority ?A)
(setq org-lowest-priority ?C)
(setq org-default-priority ?A)

;;set colours for priorities
(setq org-priority-faces '((?A . (:foreground "#F0DFAF" :weight bold))
                           (?B . (:foreground "LightSteelBlue"))
                           (?C . (:foreground "OliveDrab"))))

;;open agenda in current window
(setq org-agenda-window-setup (quote reorganize-frame))
(setq org-agenda-restore-windows-after-quit )				;


(setq org-deadline-warning-days 7)

(setq org-agenda-start-on-weekday 1) 

(setq org-agenda-custom-commands
      '(("v" "Mon agenda" agenda ""
         ((org-agenda-ndays 7)          ;; agenda will start in week view
          (org-agenda-repeating-timestamp-show-all t)   ;; ensures that repeating events appear on all relevant dates
	  (org-agenda-files '("~/org/vic.org")) ;; Only my own agenda
          (org-agenda-skip-function '(org-agenda-skip-entry-if 'deadline 'scheduled)))) ;; limits agenda view to timestamped items
	("e" "Avec Estelle et Arthur" agenda ""
         ((org-agenda-ndays 7)          ;; agenda will start in week view
          (org-agenda-repeating-timestamp-show-all t)   ;; ensures that repeating events appear on all relevant dates
	  (org-agenda-files '("~/org/")) ;; All agenda files
          (org-agenda-skip-function '(org-agenda-skip-entry-if 'deadline 'scheduled))))
	
	("v" "Agenda just vic" agenda ""
	 ((org-agenda-entry-types '(vic)) ))
	("n" "Agenda and all TODOs" ((agenda "" nil) (alltodo "" nil)) nil)
	("c" "Calendar view" vic/cfw:open-org-calendar "" nil)
	))

;;capture todo items using C-c c t
(define-key global-map (kbd "C-c c") 'org-capture)
(setq org-default-notes-file (concat org-directory "/notes.org"))

(setq org-capture-templates
      '(("e" "event" entry (file "vic.org")
	 "* %^{Heading} %i %?\n %^t \n %a\n")
	("t" "todo" entry (file+headline "~/org/todo.org" "En général")
	 "* TODO [#B] %i %?\nSCHEDULED: %^t\n %a\n")
	;; For mu4e. From http://pragmaticemacs.com/emacs/master-your-inbox-with-mu4e-and-org-mode/ (see above)
	("m" "todo mails" entry (file+headline "~/org/todo.org" "Mails")
	 "* TODO [#A] %? :mails: \nSCHEDULED: %(org-insert-time-stamp (org-read-date nil t \"+0d\"))\n%a\n")
	("r" "todo terrain" entry (file+headline "~/org/todo.org" "Terrain")
	 "* TODO [#B] %i %?\nSCHEDULED: %^t\n %a\n")
	("l" "todo site lesc" entry (file+headline "~/org/sitelesc_todo.org" "New")
	 "* TODO [#B] %i %? :site: \nSCHEDULED: %^t\n %a\n")
	("c" "todo crem" entry (file+headline "~/org/todo.org" "Crem")
	 "* TODO [#B] %i %? :crem: \nSCHEDULED: %^t\n %a\n")))


(global-set-key "\C-c L" 'org-insert-link-global)
(global-set-key "\C-c o" 'org-open-at-point-global)

(require 'org-mime)
(setq org-mime-library 'mml)


;; sort tasks in order of when they are due and then by priority
(setq org-agenda-sorting-strategy
  (quote
   ((agenda deadline-up priority-down)
    (todo priority-down category-keep)
    (tags priority-down category-keep)
    (search category-keep))))

(setq
 org-agenda-files '("~/org")
 org-icalendar-include-todo (quote t)
 ;; org-icalendar-store-UID t
 org-icalendar-timezone "GMT+2 CEST"
 org-icalendar-use-scheduled (quote (event-if-not-todo todo-start))
 ;; org-icalendar-use-scheduled (quote (nil))
 org-log-done (quote time)
 org-replace-disputed-keys nil)
